from .collection import (
  CollectionCallSpanCapture
)


__all__ = [
  'CollectionCallSpanCapture'
]
